======================================
 2021-06-02 'OpenStack ATC' definition
======================================

The OpenStack Foundation bylaws defines the term
``Active Technical Contributors (“ATC”)`` as those who contribute
code in any of the OpenStack official projects, members doing any
technical contribution such as bug triage and technical documentation
writers. Bylaws require Technical Committee to maintain a list of ATCs
and their contact information.

In the Technical Committee, the term ``Active Technical Contributors
(“ATC”)`` is now renamed to ``Active Contributors (“AC”)``. As required
by bylaws, the ``Active Contributors (“AC”)`` list will be maintained
by the Technical Committee

This TC resolution therefore affirms that the ``Active Technical Contributors
(“ATC”)`` and ``Active Contributors (“AC”)`` are the same thing.
